Name:           python-email-validator
Version:        2.1.0
Release:    1%{?dist}
Summary:        A robust email syntax and deliverability validation library

License:        CC0-1.0
URL:            https://github.com/JoshData/python-email-validator
Source0:         %{url}/archive/v%{version}/python-email-validator-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  %{py3_dist pytest}

%global _description %{expand:
This library validates that a string is of the form name@example.com and
optionally checks that the domain name is set up to receive email. This is the
sort of validation you would want when you are identifying users by their email
address like on a registration/login form (but not necessarily for composing an
email message).

Key features:

  • Checks that an email address has the correct syntax – good for
    registration/login forms or other uses related to identifying users.
  • Gives friendly English error messages when validation fails that you can
    display to end-users.
  • Checks deliverability (optional): Does the domain name resolve? (You can
    override the default DNS resolver to add query caching.)
  • Supports internationalized domain names and internationalized local parts.
  • Rejects addresses with unsafe Unicode characters, obsolete email address
    syntax that you’d find unexpected, special use domain names like
    @localhost, and domains without a dot by default. This is an opinionated
    library!
  • Normalizes email addresses (important for internationalized and
    quoted-string addresses!)
  • Python type annotations are used.}

%description %{_description}

%package -n     python3-email-validator
Summary:        %{summary}

%description -n python3-email-validator %{_description}

%prep
%autosetup -n python-email-validator-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files email_validator

%check
ignore="${ignore-} --ignore=tests/test_deliverability.py"
ignore="${ignore-} --ignore=tests/test_main.py"
%pytest -v tests -m 'not network' ${ignore-}

%files -n python3-email-validator -f %{pyproject_files}
%doc CHANGELOG.md README.md
%{_bindir}/email_validator

%changelog
* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.0-1
- initial build
